@@ -254,24 +254,24 @@ module Braintree
         {:installments => [:count]},
         {:line_items => [:commodity_code, :description, :discount_amount, :image_url, :kind, :name, :product_code, :quantity, :tax_amount, :total_amount, :unit_amount, :unit_of_measure, :unit_tax_amount, :upc_code, :upc_type, :url]},
         {:options => [
-          :hold_in_escrow,
-          :store_in_vault,
-          :store_in_vault_on_success,
-          :submit_for_settlement,
           :add_billing_address_to_payment_method,
-          :store_shipping_address_in_vault,
-          :venmo_sdk_session, # Deprecated
+          {:amex_rewards => [:request_id, :points, :currency_amount, :currency_iso_code]},
+          {:credit_card => [:account_type, :process_debit_as_credit]},
+          :hold_in_escrow,
           :payee_id,
           :payee_email,
+          {:paypal => [:custom_field, :description, :payee_id, :payee_email, :recipient_email,  {:recipient_phone => [:country_code, :national_number]}, {:supplementary_data => :_any_key_}]},
+          {:processing_overrides => [:customer_email, :customer_first_name, :customer_last_name, :customer_tax_identifier]},
           :skip_advanced_fraud_checking,
           :skip_avs,
           :skip_cvv,
-          {:paypal => [:custom_field, :payee_id, :payee_email, :description, {:supplementary_data => :_any_key_}]},
-          {:processing_overrides => [:customer_email, :customer_first_name, :customer_last_name, :customer_tax_identifier]},
+          :store_in_vault,
+          :store_in_vault_on_success,
+          :store_shipping_address_in_vault,
+          :submit_for_settlement,
           {:three_d_secure => [:required]},
-          {:amex_rewards => [:request_id, :points, :currency_amount, :currency_iso_code]},
           {:venmo => [:profile_id]},
-          {:credit_card => [:account_type, :process_debit_as_credit]},
+          :venmo_sdk_session, # Deprecated
         ]
         },
         {:paypal_account => [:email, :token, :paypal_data, :payee_id, :payee_email, :payer_id, :payment_id]},
